MyNull class

Helper for injecting nullable values.

Constructors

MyNull()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

inject<T extends Object?>({bool autoDispose = true, void initState()?, void onSetState(SnapState<T?> state)?, void onAfterBuild()?, void onDispose()?}) Injected<T?>
injectDisposable<T extends Object?>({void initState()?, void onSetState(SnapState<T?> state)?, void onAfterBuild()?, void onDispose()?}) Injected<T?>